instrumenttools.UntunedPercussion
=================================

.. abjad-lineage:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion

.. autoclass:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion.UntunedPercussion.__repr__
   :noindex:
